@@ -1755,6 +1755,8 @@ int main(int argc, char **argv)
 
     QTextStream h(&header);
 
+    h.setCodec("utf-8");
+
     h << "// This file is generated by kconfig_compiler_kf5 from " << QFileInfo(inputFilename).fileName() << "." << endl;
     h << "// All changes you do to this file will be lost." << endl;
 
@@ -2120,7 +2122,7 @@ int main(int argc, char **argv)
     }
 
     if (hasNonModifySignals) {
-        h << "    virtual bool usrSave();" << endl;
+        h << "    bool usrSave() Q_DECL_OVERRIDE;" << endl;
     }
 
     // Member variables
@@ -2216,6 +2218,8 @@ int main(int argc, char **argv)
 
     QTextStream cpp(&implementation);
 
+    cpp.setCodec("utf-8");
+
     cpp << "// This file is generated by kconfig_compiler_kf5 from " << QFileInfo(inputFilename).fileName() << "." << endl;
     cpp << "// All changes you do to this file will be lost." << endl << endl;
 
@@ -2591,10 +2595,10 @@ int main(int argc, char **argv)
     // Destructor
     cpp << cfg.className << "::~" << cfg.className << "()" << endl;
     cpp << "{" << endl;
+    if (cfg.dpointer) {
+        cpp << "  delete d;" << endl;
+    }
     if (cfg.singleton) {
-        if (cfg.dpointer) {
-            cpp << "  delete d;" << endl;
-        }
         cpp << "  s_global" << cfg.className << "()->q = 0;" << endl;
     }
     cpp << "}" << endl << endl;
